@@ -12,7 +12,7 @@ def m(request, *args, **kwargs):
 @application.route("/version/<id>")
 def show_version(request, *args, **kwargs):
     if kwargs["id"] == "relational":
-        return "1.2"
+        return "2.0"
     return "No version"
 
 @application.route('/feedback/<id>')
@@ -24,11 +24,12 @@ def mail_sender(request, *args, **kwargs):
     message = ""
     for k,v in request.POST.iteritems():
         message += "%s: %s\n" % (k,v)
+    message += "ip address: %s\n" % str(request.remote_addr)
 
     if kwargs["id"] == "relational":
         from google.appengine.api import mail
 
-        mail.send_mail(sender="Feedback service <tiposchi@tiscali.it>",
+        mail.send_mail(sender="Feedback service <noreply@feedback-ltworf.appspotmail.com>",
             to="tiposchi@tiscali.it",
               subject="Feedback from %s" % kwargs["id"],
               body=message)
