@@ -41,7 +41,8 @@
 # Language definition here:
 # https://github.com/ltworf/relational/wiki/Grammar-and-language
 import re
-import rtypes
+
+from relational import rtypes
 
 RELATION = 0
 UNARY = 1
@@ -49,13 +50,13 @@ BINARY = 2
 
 PRODUCT = u'*'
 DIFFERENCE = u'-'
-UNION = u'ᑌ'
-INTERSECTION = u'ᑎ'
+UNION = u'∪'
+INTERSECTION = u'∩'
 DIVISION = u'÷'
-JOIN = u'ᐅᐊ'
-JOIN_LEFT = u'ᐅLEFTᐊ'
-JOIN_RIGHT = u'ᐅRIGHTᐊ'
-JOIN_FULL = u'ᐅFULLᐊ'
+JOIN = u'⋈'
+JOIN_LEFT = u'⧑'
+JOIN_RIGHT = u'⧒'
+JOIN_FULL = u'⧓'
 PROJECTION = u'π'
 SELECTION = u'σ'
 RENAME = u'ρ'
@@ -104,10 +105,10 @@ class node (object):
         # If the list contains only a list, it will consider the lower level list.
         # This will allow things like ((((((a))))) to work
         while len(expression) == 1 and isinstance(expression[0], list):
-                expression = expression[0]
+            expression = expression[0]
 
         # The list contains only 1 string. Means it is the name of a relation
-        if len(expression) == 1 and isinstance(expression[0], unicode):
+        if len(expression) == 1:
             self.kind = RELATION
             self.name = expression[0]
             if not rtypes.is_valid_relation_name(self.name):
@@ -125,7 +126,7 @@ class node (object):
         Since it searches for strings, and expressions into parenthesis are
         within sub-lists, they won't be found here, ensuring that they will
         have highest priority.'''
-        for i in xrange(len(expression) - 1, -1, -1):
+        for i in range(len(expression) - 1, -1, -1):
             if expression[i] in b_operators:  # Binary operator
                 self.kind = BINARY
                 self.name = expression[i]
@@ -142,7 +143,7 @@ class node (object):
                 self.right = node(expression[i + 1:])
                 return
         '''Searches for unary operators, parsing from right to left'''
-        for i in xrange(len(expression) - 1, -1, -1):
+        for i in range(len(expression) - 1, -1, -1):
             if expression[i] in u_operators:  # Unary operator
                 self.kind = UNARY
                 self.name = expression[i]
@@ -217,7 +218,7 @@ class node (object):
             return
 
         if self.kind == RELATION:
-            return list(rels[self.name].header.attributes)
+            return list(rels[self.name].header)
         elif self.kind == BINARY and self.name in (DIFFERENCE, UNION, INTERSECTION):
             return self.left.result_format(rels)
         elif self.kind == BINARY and self.name == DIVISION:
@@ -293,9 +294,6 @@ def tokenize(expression):
     '''This function converts an expression into a list where
     every token of the expression is an item of a list. Expressions into
     parenthesis will be converted into sublists.'''
-    if not isinstance(expression, unicode):
-        raise TokenizerException('expected unicode')
-
     items = []  # List for the tokens
 
     '''This is a state machine. Initial status is determined by the starting of the
@@ -332,9 +330,9 @@ def tokenize(expression):
             # Removes the entire parentesis and content from the expression
             expression = expression[end + 1:].strip()
 
-        elif expression.startswith((u"σ", u"π", u"ρ")):  # Unary 2 bytes
+        elif expression.startswith((SELECTION, RENAME, PROJECTION)):  # Unary 2 bytes
             items.append(expression[0:1])
-                         #Adding operator in the top of the list
+                         # Adding operator in the top of the list
             expression = expression[
                 1:].strip()  # Removing operator from the expression
 
@@ -345,20 +343,13 @@ def tokenize(expression):
                 par = expression.find('(')
 
             items.append(expression[:par].strip())
-                         #Inserting parameter of the operator
+                         # Inserting parameter of the operator
             expression = expression[
                 par:].strip()  # Removing parameter from the expression
-        elif expression.startswith((u"÷", u"ᑎ", u"ᑌ", u"*", u"-")):
+        elif expression.startswith((DIVISION, INTERSECTION, UNION, PRODUCT, DIFFERENCE, JOIN, JOIN_LEFT, JOIN_RIGHT, JOIN_FULL)):
             items.append(expression[0])
             expression = expression[1:].strip()  # 1 char from the expression
             state = 4
-        elif expression.startswith(u"ᐅ"):  # Binary long
-            i = expression.find(u"ᐊ")
-            if i == -1:
-                raise TokenizerException(u"Expected ᐊ in %s" % (expression,))
-            items.append(expression[:i + 1])
-            expression = expression[i + 1:].strip()
-            state = 4
         elif re.match(r'[_0-9A-Za-z]', expression[0]) == None:  # At this point we only have relation names, so we raise errors for anything else
             raise TokenizerException(
                 "Unexpected '%c' in '%s'" % (expression[0], expression))
@@ -417,8 +408,8 @@ def parse(expr):
 
 if __name__ == "__main__":
     while True:
-        e = unicode(raw_input("Expression: "), 'utf-8')
-        print parse(e)
+        e = input("Expression: ")
+        print (parse(e))
 
     # b=u"σ age>1 and skill=='C' (peopleᐅᐊskills)"
     # print b[0]
