@@ -20,8 +20,11 @@
 # This module provides a classes to represent relations and to perform
 # relational operations on them.
 
-from rtypes import *
 import csv
+from itertools import chain, repeat
+from collections import deque
+
+from relational.rtypes import *
 
 
 class relation (object):
@@ -45,18 +48,14 @@ class relation (object):
             self.content = set()
             self.header = header([])
             return
-        # Opening file
-        fp = file(filename)
+        with open(filename) as fp:
+            reader = csv.reader(fp)  # Creating a csv reader
+            self.header = header(next(reader))  # read 1st line
+            self.content = set()
+            attributes = len(self.header)
 
-        reader = csv.reader(fp)  # Creating a csv reader
-        self.header = header(reader.next())  # read 1st line
-        self.content = set()
-
-        for i in reader.__iter__():  # Iterating rows
-            self.content.add(tuple(i))
-
-        # Closing file
-        fp.close()
+            iterator = ((self.insert(i) for i in reader))
+            deque(iterator, maxlen=0)
 
     def _make_writable(self):
         '''If this relation is marked as readonly, this
@@ -66,18 +65,24 @@ class relation (object):
             self.content = set(self.content)
             self._readonly = False
 
+    def __iter__(self):
+        return iter(self.content)
+
+    def __contains__(self, key):
+        return key in self.content
+
     def save(self, filename):
         '''Saves the relation in a file. By default will save using the csv
         format as defined in RFC4180, but setting comma_separated to False,
         it will use the old format with space separated values.
         '''
 
-        fp = file(filename, 'w')  # Opening file in write mode
+        fp = open(filename, 'w')  # Opening file in write mode
 
         writer = csv.writer(fp)  # Creating csv writer
 
         # It wants an iterable containing iterables
-        head = (self.header.attributes,)
+        head = (self.header,)
         writer.writerows(head)
 
         # Writing content, already in the correct format
@@ -91,39 +96,28 @@ class relation (object):
         internally.
         Will return None if they don't share the same attributes'''
         if (self.__class__ != other.__class__):
-            return None
-        if self.header.sharedAttributes(other.header) == len(self.header.attributes) == len(other.header.attributes):
-            return other.projection(list(self.header.attributes))
-        return None
-
-    def _autocast(self, string):
-        '''Depending on the regexp matched by the string,
-        it will perform automatic casting'''
-        tmpstring = rstring(string)
-        if len(tmpstring) > 0 and tmpstring.isInt():
-            return int(tmpstring)
-        elif len(tmpstring) > 0 and tmpstring.isFloat():
-            return float(tmpstring)
-        elif len(tmpstring) > 0 and tmpstring.isDate():
-            return rdate(tmpstring)
-        else:
-            return tmpstring
+            raise Exception('Expected an instance of the same class')
+        if self.header.sharedAttributes(other.header) == len(self.header):
+            return other.projection(self.header)
+        raise Exception('Relations differ: [%s] [%s]' % (
+            ','.join(self.header) , ','.join(other.header)
+            ))
 
     def selection(self, expr):
         '''Selection, expr must be a valid boolean expression, can contain field names,
         constant, math operations and boolean ones.'''
         attributes = {}
         newt = relation()
-        newt.header = header(list(self.header.attributes))
+        newt.header = header(self.header)
         for i in self.content:
             # Fills the attributes dictionary with the values of the tuple
-            for j in range(len(self.header.attributes)):
-                attributes[self.header.attributes[j]] = self._autocast(i[j])
+            for j,attr in enumerate(self.header):
+                attributes[attr] = i[j].autocast()
 
             try:
                 if eval(expr, attributes):
                     newt.content.add(i)
-            except Exception, e:
+            except Exception as e:
                 raise Exception(
                     "Failed to evaluate %s\n%s" % (expr, e.__str__()))
         return newt
@@ -138,7 +132,7 @@ class relation (object):
             raise Exception(
                 'Unable to perform product on relations with colliding attributes')
         newt = relation()
-        newt.header = header(self.header.attributes + other.header.attributes)
+        newt.header = header(self.header + other.header)
 
         for i in self.content:
             for j in other.content:
@@ -151,32 +145,21 @@ class relation (object):
         Will delete duplicate items
         If an empty list or no parameters are provided, returns None'''
         # Parameters are supplied in a list, instead with multiple parameters
-        if isinstance(attributes[0], list):
+        if not isinstance(attributes[0], str):
             attributes = attributes[0]
 
-        # Avoiding duplicated attributes
-        attributes1 = []
-        for i in attributes:
-            if i not in attributes1:
-                attributes1.append(i)
-        attributes = attributes1
-
         ids = self.header.getAttributesId(attributes)
 
-        if len(ids) == 0 or len(ids) != len(attributes):
+        if len(ids) == 0:
             raise Exception('Invalid attributes for projection')
         newt = relation()
         # Create the header
-        h = []
-        for i in ids:
-            h.append(self.header.attributes[i])
+        h = (self.header[i] for i in ids)
         newt.header = header(h)
 
         # Create the body
         for i in self.content:
-            row = []
-            for j in ids:
-                row.append(i[j])
+            row = (i[j] for j in ids)
             newt.content.add(tuple(row))
         return newt
 
@@ -188,14 +171,11 @@ class relation (object):
         result = []
 
         newt = relation()
-        newt.header = header(list(self.header.attributes))
-
-        for old, new in params.iteritems():
-            if (newt.header.rename(old, new)) == False:
-                raise Exception('Unable to find attribute: %s' % old)
+        newt.header = self.header.rename(params)
 
         newt.content = self.content
         newt._readonly = True
+        self._readonly = True
         return newt
 
     def intersection(self, other):
@@ -205,11 +185,8 @@ class relation (object):
         Will return None if headers are different.
         It is possible to use projection and rename to make headers match.'''
         other = self._rearrange_(other)  # Rearranges attributes' order
-        if (self.__class__ != other.__class__)or(self.header != other.header):
-            raise Exception(
-                'Unable to perform intersection on relations with different attributes')
         newt = relation()
-        newt.header = header(list(self.header.attributes))
+        newt.header = header(self.header)
 
         newt.content = self.content.intersection(other.content)
         return newt
@@ -221,11 +198,8 @@ class relation (object):
         Will return None if headers are different.
         It is possible to use projection and rename to make headers match.'''
         other = self._rearrange_(other)  # Rearranges attributes' order
-        if (self.__class__ != other.__class__)or(self.header != other.header):
-            raise Exception(
-                'Unable to perform difference on relations with different attributes')
         newt = relation()
-        newt.header = header(list(self.header.attributes))
+        newt.header = header(self.header)
 
         newt.content = self.content.difference(other.content)
         return newt
@@ -240,8 +214,7 @@ class relation (object):
         '''
 
         # d_headers are the headers from self that aren't also headers in other
-        d_headers = list(
-            set(self.header.attributes) - set(other.header.attributes))
+        d_headers = tuple(set(self.header) - set(other.header))
 
         '''
         Wikipedia defines the division as follows:
@@ -267,11 +240,8 @@ class relation (object):
         Will return None if headers are different.
         It is possible to use projection and rename to make headers match.'''
         other = self._rearrange_(other)  # Rearranges attributes' order
-        if (self.__class__ != other.__class__)or(self.header != other.header):
-            raise Exception(
-                'Unable to perform union on relations with different attributes')
         newt = relation()
-        newt.header = header(list(self.header.attributes))
+        newt.header = header(self.header)
 
         newt.content = self.content.union(other.content)
         return newt
@@ -302,30 +272,21 @@ class relation (object):
         problems when saving the relation.
         Just like natural join, it works considering shared attributes.'''
 
-        shared = []
-        for i in self.header.attributes:
-            if i in other.header.attributes:
-                shared.append(i)
+        shared = self.header.intersection(other.header)
 
         newt = relation()  # Creates the new relation
+        # Creating the header with all the fields, done like that because order is
+        # needed
+        h = (i for i in other.header if i not in shared)
+        newt.header = header(chain(self.header,h))
 
-        # Adds all the attributes of the 1st relation
-        newt.header = header(list(self.header.attributes))
-
-        # Adds all the attributes of the 2nd, when non shared
-        for i in other.header.attributes:
-            if i not in shared:
-                newt.header.attributes.append(i)
         # Shared ids of self
         sid = self.header.getAttributesId(shared)
         # Shared ids of the other relation
         oid = other.header.getAttributesId(shared)
 
         # Non shared ids of the other relation
-        noid = []
-        for i in range(len(other.header.attributes)):
-            if i not in oid:
-                noid.append(i)
+        noid = [i for i in range(len(other.header)) if i not in oid]
 
         for i in self.content:
             # Tuple partecipated to the join?
@@ -336,17 +297,13 @@ class relation (object):
                     match = match and (i[sid[k]] == j[oid[k]])
 
                 if match:
-                    item = list(i)
-                    for l in noid:
-                        item.append(j[l])
+                    item = chain(i,(j[l] for l in noid))
 
                     newt.content.add(tuple(item))
                     added = True
             # If it didn't partecipate, adds it
             if not added:
-                item = list(i)
-                for l in range(len(noid)):
-                    item.append("---")
+                item = chain(i,repeat('---',len(noid)))
                 newt.content.add(tuple(item))
 
         return newt
@@ -356,17 +313,14 @@ class relation (object):
         shared attributes, it will behave as cartesian product.'''
 
         # List of attributes in common between the relations
-        shared = list(set(self.header.attributes)
-                      .intersection(set(other.header.attributes)))
+        shared = self.header.intersection(other.header)
 
         newt = relation()  # Creates the new relation
 
-        # Adding to the headers all the fields, done like that because order is
+        # Creating the header with all the fields, done like that because order is
         # needed
-        newt.header = header(list(self.header.attributes))
-        for i in other.header.attributes:
-            if i not in shared:
-                newt.header.attributes.append(i)
+        h = (i for i in other.header if i not in shared)
+        newt.header = header(chain(self.header,h))
 
         # Shared ids of self
         sid = self.header.getAttributesId(shared)
@@ -374,10 +328,7 @@ class relation (object):
         oid = other.header.getAttributesId(shared)
 
         # Non shared ids of the other relation
-        noid = []
-        for i in range(len(other.header.attributes)):
-            if i not in oid:
-                noid.append(i)
+        noid = [i for i in range(len(other.header)) if i not in oid]
 
         for i in self.content:
             for j in other.content:
@@ -386,10 +337,7 @@ class relation (object):
                     match = match and (i[sid[k]] == j[oid[k]])
 
                 if match:
-                    item = list(i)
-                    for l in noid:
-                        item.append(j[l])
-
+                    item = chain(i, (j[l] for l in noid))
                     newt.content.add(tuple(item))
 
         return newt
@@ -397,23 +345,26 @@ class relation (object):
     def __eq__(self, other):
         '''Returns true if the relations are the same, ignoring order of items.
         This operation is rather heavy, since it requires sorting and comparing.'''
-        other = self._rearrange_(
-            other)  # Rearranges attributes' order so can compare tuples directly
-
-        if (self.__class__ != other.__class__)or(self.header != other.header):
-            return False  # Both parameters must be a relation
-
-        if set(self.header.attributes) != set(other.header.attributes):
+        if self.__class__ != other.__class__:
             return False
 
+        if set(self.header) != set(other.header):
+            return False
+
+        # Rearranges attributes' order so can compare tuples directly
+        other = self._rearrange_(other)
+
         # comparing content
         return self.content == other.content
 
+    def __len__(self):
+        return len(self.content)
+
     def __str__(self):
         '''Returns a string representation of the relation, can be printed with
         monospaced fonts'''
         m_len = []  # Maximum lenght string
-        for f in self.header.attributes:
+        for f in self.header:
             m_len.append(len(f))
 
         for f in self.content:
@@ -424,8 +375,8 @@ class relation (object):
                 col += 1
 
         res = ""
-        for f in range(len(self.header.attributes)):
-            res += "%s" % (self.header.attributes[f].ljust(2 + m_len[f]))
+        for f,attr in enumerate(self.header):
+            res += "%s" % (attr.ljust(2 + m_len[f]))
 
         for r in self.content:
             col = 0
@@ -453,8 +404,8 @@ class relation (object):
 
         # new_content=[] #New content of the relation
         for i in self.content:
-            for j in range(len(self.header.attributes)):
-                attributes[self.header.attributes[j]] = self._autocast(i[j])
+            for j,attr in enumerate(self.header):
+                attributes[attr] = i[j].autocast()
 
             if eval(expr, attributes):  # If expr is true, changing the tuple
                 affected += 1
@@ -464,7 +415,7 @@ class relation (object):
                 # being affected.
                 self.content.remove(i)
                 for k in range(len(keys)):
-                    new_tuple[f_ids[k]] = str(dic[keys[k]])
+                    new_tuple[f_ids[k]] = rstring(dic[keys[k]])
                 self.content.add(tuple(new_tuple))
         return affected
 
@@ -474,19 +425,18 @@ class relation (object):
         All the values will be converted in string.
         Will return the number of inserted rows.'''
 
-        # Returns if tuple doesn't fit the number of attributes
-        if len(self.header.attributes) != len(values):
-            return 0
+        if len(self.header) != len(values):
+            raise Exception(
+                'Tuple has the wrong size. Expected %d, got %d' % (
+                    len(self.header),
+                    len(values)
+                )
+            )
 
         self._make_writable()
 
-        # Creating list containing only strings
-        t = []
-        for i in values:
-            t.append(str(i))
-
         prevlen = len(self.content)
-        self.content.add(tuple(t))
+        self.content.add(tuple(map(rstring, values)))
         return len(self.content) - prevlen
 
     def delete(self, expr):
@@ -495,73 +445,65 @@ class relation (object):
         This operation will change the relation itself instead of generating a new one,
         deleting all the tuples that make expr true.
         Returns the number of affected rows.'''
-        self._make_writable()
-        attributes = {}
-        affected = len(self.content)
-        new_content = set()  # New content of the relation
-        for i in self.content:
-            for j in range(len(self.header.attributes)):
-                attributes[self.header.attributes[j]] = self._autocast(i[j])
 
-            if not eval(expr, attributes):
-                affected -= 1
-                new_content.add(i)
-        self.content = new_content
-        return affected
+        #Not necessary self._make_writable()
+
+        l = len(self.content)
+        self._readonly = False
+        self.content = self.difference(self.selection(expr)).content
+        return len(self.content) - l
 
 
-class header (object):
+class header(tuple):
 
     '''This class defines the header of a relation.
     It is used within relations to know if requested operations are accepted'''
 
     # Since relations are mutalbe we explicitly block hashing them
-    __hash__ = None
+    def __new__ (cls, fields):
+        return super(header, cls).__new__(cls, tuple(fields))
 
-    def __init__(self, attributes):
+    def __init__(self, *args, **kwargs):
         '''Accepts a list with attributes' names. Names MUST be unique'''
-        self.attributes = attributes
 
-        for i in attributes:
+        for i in self:
             if not is_valid_relation_name(i):
                 raise Exception('"%s" is not a valid attribute name' % i)
 
+        if len(self) != len(set(self)):
+            raise Exception('Attribute names must be unique')
+
     def __repr__(self):
-        return "header(%s)" % (self.attributes.__repr__())
+        return "header(%s)" % super(header, self).__repr__()
 
-    def rename(self, old, new):
-        '''Renames a field. Doesn't check if it is a duplicate.
-        Returns True if the field was renamed, False otherwise'''
+    def rename(self, params):
+        '''Returns a new header, with renamed fields.
 
-        if not is_valid_relation_name(new):
-            raise Exception('%s is not a valid attribute name' % new)
-
-        try:
-            id_ = self.attributes.index(old)
-            self.attributes[id_] = new
-        except:
-            return False
-        return True
+        params is a dictionary of {old:new} names
+        '''
+        attrs = list(self)
+        for old,new in params.items():
+            if not is_valid_relation_name(new):
+                raise Exception('%s is not a valid attribute name' % new)
+            try:
+                id_ = attrs.index(old)
+                attrs[id_] = new
+            except:
+                raise Exception('Field not found: %s' % old)
+        return header(attrs)
 
     def sharedAttributes(self, other):
         '''Returns how many attributes this header has in common with a given one'''
-        return len(set(self.attributes).intersection(set(other.attributes)))
+        return len(set(self).intersection(set(other)))
 
-    def __str__(self):
-        '''Returns String representation of the field's list'''
-        return self.attributes.__str__()
+    def union(self, other):
+        '''Returns the union of the sets of attributes with another header.'''
+        return set(self).union(set(other))
 
-    def __eq__(self, other):
-        return self.attributes == other.attributes
-
-    def __ne__(self, other):
-        return self.attributes != other.attributes
+    def intersection(self, other):
+        '''Returns the set of common attributes with another header.'''
+        return set(self).intersection(set(other))
 
     def getAttributesId(self, param):
         '''Returns a list with numeric index corresponding to field's name'''
-        res = []
-        for i in param:
-            for j in range(len(self.attributes)):
-                if i == self.attributes[j]:
-                    res.append(j)
-        return res
+        return [self.index(i) for i in param]
