@@ -28,6 +28,25 @@ import re
 class rstring (str):
 
     '''String subclass with some custom methods'''
+    def autocast(self):
+        '''
+        Returns the automatic cast for this
+        value.
+        '''
+        try:
+            return self._autocast
+        except:
+            pass
+
+        self._autocast = self
+        if len(self) > 0:
+            if self.isInt():
+                self._autocast = int(self)
+            elif self.isFloat():
+                self._autocast = float(self)
+            elif self.isDate():
+                self._autocast = rdate(self)
+        return self._autocast
 
     def isInt(self):
         '''Returns true if the string represents an int number
