@@ -21,13 +21,13 @@ from distutils.core import setup
 
 def c_setup(name):
     setup(
-        version='1.1',
+        version='2.0',
         name=name,
         packages=(name,),
         author="Salvo 'LtWorf' Tomaselli",
         author_email='tiposchi@tiscali.it',
         maintainer="Salvo 'LtWorf' Tomaselli",
         maintainer_email='tiposchi@tiscali.it',
-        url='https://github.com/ltworf/relational',
+        url='http://ltworf.github.io/relational/',
         license='GPL3',
     )
